@@ -513,17 +513,23 @@ class LocalizedText(FrozenClass):
             ('Locale', 'String'),
             ('Text', 'String'), )
 
-    def __init__(self, text=None):
+    def __init__(self, text=None, locale=None):
         self.Encoding = 0
         self._text = None
+        self._locale = None
         if text:
             self.Text = text
-        self.Locale = None
+        if locale:
+            self.Locale = locale
         self._freeze = True
 
     @property
     def Text(self):
         return self._text
+    
+    @property
+    def Locale(self):
+        return self._locale
 
     @Text.setter
     def Text(self, text):
@@ -536,12 +542,31 @@ class LocalizedText(FrozenClass):
         self._text = text
         if self._text:
             self.Encoding |= (1 << 1)
+            
+    @Locale.setter
+    def Locale(self, locale):
+        if not isinstance(locale, str):
+            raise ValueError("A LocalizedText object takes a string as argument, not a {}, {}".format({type(locale)}, {locale}))
+        self._locale = locale
+        if self._locale:
+            self.Encoding |= (1)
 
     def to_string(self):
-        # FIXME: use local
         if self.Text is None:
             return ""
-        return self.Text
+        if not self.Locale:
+            return self.Text
+        return self.__str__()
+    
+    @staticmethod
+    def from_string(string):
+        m = re.match(r"^LocalizedText\(Encoding:(.*), Locale:(.*), Text:(.*)\)$", string)
+        if m:
+            text = m.group(3) if m.group(3) != str(None) else None
+            locale = m.group(2) if m.group(2) != str(None) else None
+            return LocalizedText(text=text, locale=locale)
+        else:
+            return LocalizedText(string)
 
     def __str__(self):
         return 'LocalizedText(' + 'Encoding:' + str(self.Encoding) + ', ' + \
@@ -891,8 +916,8 @@ class DataValue(FrozenClass):
             ('ServerTimestamp', 'DateTime'),
             ('ServerPicoseconds', 'UInt16'),
             )
-
-    def __init__(self, variant=None, status=None):
+    
+    def __init__(self, variant=None, status=None, sourceTimestamp=None, sourcePicoseconds=None, serverTimestamp=None, serverPicoseconds=None):
         self.Encoding = 0
         if not isinstance(variant, Variant):
             variant = Variant(variant)
@@ -901,10 +926,10 @@ class DataValue(FrozenClass):
             self.StatusCode = StatusCode()
         else:
             self.StatusCode = status
-        self.SourceTimestamp = None  # DateTime()
-        self.SourcePicoseconds = None
-        self.ServerTimestamp = None  # DateTime()
-        self.ServerPicoseconds = None
+        self.SourceTimestamp = sourceTimestamp
+        self.SourcePicoseconds = sourcePicoseconds
+        self.ServerTimestamp = serverTimestamp
+        self.ServerPicoseconds = serverPicoseconds
         self._freeze = True
 
     def __str__(self):
