@@ -299,7 +299,12 @@ class SecureConnection(object):
         if header.MessageType == ua.MessageType.SecureOpen:
             data = body.copy(header.body_size)
             security_header = struct_from_binary(ua.AsymmetricAlgorithmHeader, data)
-            self.select_policy(security_header.SecurityPolicyURI, security_header.SenderCertificate)
+
+            if not self.is_open():
+                # Only call select_policy if the channel isn't open. Otherwise
+                # it will break the Secure channel renewal.
+                self.select_policy(security_header.SecurityPolicyURI, security_header.SenderCertificate)
+
         elif header.MessageType in (ua.MessageType.SecureMessage, ua.MessageType.SecureClose):
             data = body.copy(header.body_size)
             security_header = struct_from_binary(ua.SymmetricAlgorithmHeader, data)
